pub struct HttpHealthServer { /* private fields */ }Expand description
HTTP server that exposes health endpoints
Implementations
Sourceimpl HttpHealthServer
impl HttpHealthServer
pub fn new(bind_addr: SocketAddr) -> Self
pub fn with_health_monitor(self, monitor: HealthMonitor) -> Self
pub fn with_snapshot_runtime(self, snapshot_runtime: SnapshotRuntime) -> Self
pub fn with_runtime_plan(self, runtime_plan: RuntimePlan) -> Self
pub fn with_program_runtime_catalog( self, catalog: ProgramRuntimeCatalog, ) -> Self
pub fn with_auth_plugin(self, plugin: Arc<dyn WebSocketAuthPlugin>) -> Self
pub fn with_transaction_config(self, config: TransactionConfig) -> Self
pub fn with_solana_gateway_target(self, target_id: impl Into<String>) -> Self
pub fn with_program_read_binding_target( self, target_id: impl Into<String>, ) -> Self
Sourcepub fn with_shutdown(self, token: CancellationToken) -> Self
pub fn with_shutdown(self, token: CancellationToken) -> Self
Stop accepting and return from start when token is
cancelled. Without one the server accepts until the process exits.
pub async fn start(self) -> Result<()>