pub struct SubscribedFrame {
pub protocol_version: u8,
pub subscription_id: String,
pub op: &'static str,
pub query: SubscriptionQuery,
pub mode: Mode,
pub sort: Option<SortConfig>,
pub replay_window: Option<ReplayWindow>,
}Fields
protocol_version: u8subscription_id: Stringop: &'static strquery: SubscriptionQuerymode: Modesort: Option<SortConfig>replay_window: Option<ReplayWindow>Offsets this view can replay, for append views backed by the event journal. Absent when the view has no retained tape.
Implementations
Sourceimpl SubscribedFrame
impl SubscribedFrame
pub fn new( subscription_id: String, query: SubscriptionQuery, mode: Mode, sort: Option<SortConfig>, ) -> Self
Sourcepub fn with_replay_window(self, window: ReplayWindow) -> Self
pub fn with_replay_window(self, window: ReplayWindow) -> Self
Advertise the offsets a resuming consumer can still ask for.