pub struct SolanaGatewayAuthorization {
pub subject: String,
pub issuer: String,
pub key_class: KeyClass,
pub metering_key: String,
pub target_id: String,
pub limits: Limits,
pub plan: Option<String>,
pub expires_at: u64,
pub jti: String,
}Expand description
Authorization for one regional Solana gateway binding.
Fields
subject: Stringissuer: Stringkey_class: KeyClassmetering_key: Stringtarget_id: Stringlimits: Limitsplan: Option<String>expires_at: u64jti: StringImplementations
Sourceimpl SolanaGatewayAuthorization
impl SolanaGatewayAuthorization
Sourcepub fn validate_target(
context: &AuthContext,
expected_target_id: &str,
) -> Result<(), SolanaGatewayAuthorizationError>
pub fn validate_target( context: &AuthContext, expected_target_id: &str, ) -> Result<(), SolanaGatewayAuthorizationError>
Validate only the stable audience and exact gateway target claims.
Sourcepub fn try_from_context(
context: &AuthContext,
expected_target_id: &str,
required_scope: SolanaGatewayScope,
) -> Result<SolanaGatewayAuthorization, SolanaGatewayAuthorizationError>
pub fn try_from_context( context: &AuthContext, expected_target_id: &str, required_scope: SolanaGatewayScope, ) -> Result<SolanaGatewayAuthorization, SolanaGatewayAuthorizationError>
Validate verified claims against an exact gateway binding and permission.